@@ -2,7 +2,7 @@ use warnings;
 use strict;
 
 use RPi::WiringPi;
-use RPi::WiringPi::Constant qw(:all);
+use RPi::Const qw(:all);
 
 die "need root!\n" if $> !=0;
 
